MVCAPA
===============================================

.. currentmodule:: skchange.anomaly_detectors

.. autoclass:: MVCAPA

.. include:: skchange.anomaly_detectors.MVCAPA.examples

.. raw:: html

    <div class="clearer"></div>